# canals

🌊 Carrying data from one place to another 🌊

[![PyPI - Version](https://img.shields.io/pypi/v/canals.svg)](https://pypi.org/project/canals)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/canals.svg)](https://pypi.org/project/canals)

## Installation

```console
pip install canals
```

To be able to draw pipelines
```console
sudo apt install graphviz graphviz-dev
pip install canals[draw]
```
